//==============================             настройки

#define WSPR_FREQ               7040105UL          //частота маячка
#define SI5351_REF              25000000UL         //частота опорного генератора синтезатора
#define CORRECTION              36200             // Коррекция частоты
#define tx_enable               4                 // нога включения питания PA

//настройки WSPR, не трогать
#define WSPR_TONE_SPACING       146           // ~1.46 Hz
#define WSPR_DELAY              683          // Delay value for WSPR
#define SYMBOL_COUNT            WSPR_SYMBOL_COUNT



float divider = 4.6; //делитель напряжения на входе 0 АЦП

char call[7] = "AA0AA " ; // WSPR callsign, 6 знаков, цифра в 3-й позиции
char loc[5] = {'A', 'A', '0', '0'} ; // WSPR  locator, 4 знака
byte dbm = 27; // WSPR dBm. Возможные значения -  {0, 3, 7, 10, 13, 17, 20, 23, 27, 30, 33, 37, 40, 43, 47, 50, 53, 57, 60}

//==============================


//подключаем библиотеки
#include <TimeLib.h>
#include "Wire.h" // I2C
#include <si5351.h> //
#include <JTEncode.h>


char buf[32]; //буфер
byte Hour, Minute, Second; // время
bool warmup = 0; //прогрев

Si5351 si5351;
JTEncode jtencode;

//подключаем вкладки
#include "Oled.h"
#include "adc.h"
#include "gps.h"
#include "telemetry.h"
#include "encode.h"
#include "timing.h"



void setup()
{
  oled_init(); //старт дисплея

  pinMode(tx_enable, OUTPUT); //нога включения питания PA
  digitalWrite(tx_enable, LOW);

  // Start the Arduino hardware serial port at 9600 baud
  Serial.begin(9600);

  //Инициализация GPS-модуля
  OzOled.printString("GPS init", 0, 0); //Печатаем сообщение в первой строке (адрес строки 0)
  delay(500); // пауза для инициализации модуля
  gps_set_max_performance_mode(); // Устанавливаем режим максимальной производительности
  delay(1000);//пауза, пока установится

  si5351.init(SI5351_CRYSTAL_LOAD_8PF, SI5351_REF, CORRECTION); //инициализация синтеза
  // выход CLK0
  si5351.set_freq(WSPR_FREQ * 100, SI5351_CLK0);
  si5351.drive_strength(SI5351_CLK0, SI5351_DRIVE_2MA); // Установка тока выхода Si5351. Возможные значения 2-4-6-8MA
  si5351.set_clock_pwr(SI5351_CLK0, 0); //  Ставим выход на паузу
  OzOled.clearDisplay(); //очищаем дисплей
  ad_conversion(); //измеряем батарейку, выводим на дисплей
}



void loop() {

  while (Serial.available() > 0) //принимаем данные от GPS модуля
    if (gps.encode(Serial.read())) // если данные от GPS получены

      if (gps.time.second() != Second) // выполняем цикл один раз в секунду
      {
        if (timeStatus() == timeNotSet) // корректируем время, если оно не установлено ранее
        {
          setGPStime();
        }

        //выводим время на дисплей в первой строке
        Hour = gps.time.hour();
        Minute = gps.time.minute();
        Second = gps.time.second();
        sprintf(buf, "%02d:%02d:%02d", Hour, Minute, Second);
        OzOled.printString(buf, 0, 0);

        if (gps.location.isValid()) //если координаты правильные
        {
          OzOled.printString("Data OK    ", 0, 1); //подтверждаем
          telemetry(); //считаем телеметрию
          TXtiming(); // проверяем время
        }
        else OzOled.printString("Data NOT OK", 0, 1);//иначе не подтверждаем
      }
}
